@@ -1,4 +1,4 @@
-#' @include SetInterval_operations.R
+#' @include distr6_globals.R helpers.R
 #-------------------------------------------------------------
 # Distribution Documentation
 #-------------------------------------------------------------
@@ -19,8 +19,8 @@
 #' \strong{Argument} \tab \strong{Type} \tab \strong{Details} \cr
 #' \code{name} \tab character \tab Full name of distribution. \cr
 #' \code{short_name} \tab character \tab Short name to identify distribution. \cr
-#' \code{type} \tab SetInterval \tab Scientific type. \cr
-#' \code{support} \tab SetInterval \tab Distribution support. See Details. \cr
+#' \code{type} \tab [set6::Set] \tab Scientific type. \cr
+#' \code{support} \tab [set6::Set] \tab Distribution support. See Details. \cr
 #' \code{symmetric} \tab logical \tab Is distribution symmetric? \cr
 #' \code{pdf} \tab function \tab See Details. \cr
 #' \code{cdf} \tab function \tab See Details. \cr
@@ -38,7 +38,7 @@
 #'
 #'   The most basic Distribution object consists of a name and one of pdf/cdf.
 #'
-#'   If supplied, \code{type} and \code{support} should be given as an R6 SetInterval object. If neither are supplied
+#'   If supplied, \code{type} and \code{support} should be given as a [set6::Set] object. If neither are supplied
 #'   then the set of Reals is taken to be the type and the dimension is the number of formal arguments in the pdf/cdf.
 #'   If only \code{type} is supplied then this is taken to also be the support.
 #'
@@ -123,9 +123,8 @@
 #'   }
 #'
 #'
-#' @seealso See \code{\link{SetInterval}} and \code{\link{SpecialSet}} for details on Sets and
-#' Intervals. See \code{\link{ParameterSet}} for parameter details. See
-#' \code{\link{decorate}} for Decorator details.
+#' @seealso See \CRANpkg{set6} for details on Sets and Intervals. See \code{\link{ParameterSet}} for
+#' parameter details. See \code{\link{decorate}} for Decorator details.
 #'
 #' @return Returns R6 object of class Distribution.
 #'
@@ -134,7 +133,7 @@ NULL
 #-------------------------------------------------------------
 # Distribution Definition
 #-------------------------------------------------------------
-Distribution <- R6::R6Class("Distribution", lock_objects = FALSE)
+Distribution <- R6Class("Distribution", lock_objects = FALSE)
 
 
 #-------------------------------------------------------------
@@ -149,12 +148,14 @@ Distribution$set("public","initialize",function(name = NULL, short_name = NULL,
                       ){
 
   if(.suppressChecks | inherits(self, "DistributionWrapper")){
+
     if(!is.null(parameters)) parameters = parameters$clone(deep = TRUE)
     if(!is.null(pdf)) formals(pdf) = c(formals(pdf),list(self=self),alist(...=))
     if(!is.null(cdf)) formals(cdf) = c(formals(cdf),list(self=self),alist(...=))
     if(!is.null(quantile)) formals(quantile) = c(formals(quantile),list(self=self),alist(...=))
     if(!is.null(rand)) formals(rand) = c(formals(rand),list(self=self),alist(...=))
-  } else if(getR6Class(self) == "Distribution"){
+
+  } else if(getR6Class(self) == "Distribution") {
 
     if(is.null(pdf) & is.null(cdf))
       stop("One of pdf or cdf must be provided.")
@@ -178,45 +179,37 @@ Distribution$set("public","initialize",function(name = NULL, short_name = NULL,
       rm = c("...","self")
       if(!is.null(pdf)){
         lng = length(formals(pdf)[!(names(formals(pdf)) %in% rm)])
-        type <- Reals$new(dim = lng)
+        type <- setpower(Reals$new(), lng)
       } else{
         lng = length(formals(cdf)[!(names(formals(cdf)) %in% rm)])
-        type <- Reals$new(dim = lng)
+        type <- setpower(Reals$new(), lng)
       }
     }
     if(is.null(support)) support <- type
-    checkmate::assert(inherits(type,"SetInterval"), inherits(support,"SetInterval"),
-                      .var.name = "'type' and 'support' should be class 'SetInterval'.")
+    assertSet(type)
+    assertSet(support)
 
     #--------------------
     # valueSupport Checks
     #--------------------
     if(!is.null(valueSupport)){
-      if(grepl("^c",valueSupport))
-        valueSupport = "continuous"
-      else if(grepl("^d",valueSupport))
-        valueSupport = "discrete"
-      else if(grepl("^m",valueSupport))
-        valueSupport = "mixture"
-      else
-        stop("valueSupport should be one of: 'continuous', 'discrete','mixture'.")
-    }else if(support$class() == "numeric")
+      valueSupport = match.arg(valueSupport, c("continuous", "discrete", "mixture"))
+    } else if(support$properties$countability == "uncountable") {
       valueSupport = "continuous"
-     else
+     } else {
       valueSupport = "discrete"
+     }
 
     #-------------------
     # variateForm Checks
     #-------------------
     if(!is.null(variateForm)){
-      if(grepl("^u",variateForm)) variateForm = "univariate"
-      else if(grepl("^mu",variateForm)) variateForm = "multivariate"
-      else if(grepl("^ma",variateForm)) variateForm = "matrixvariate"
-      else stop("variateForm should be one of: 'univariate', 'multivariate','matrixvariate'.")
-    } else if(type$dimension() == 1)
-      variateForm = "univariate"
-    else
+      variateForm = match.arg(variateForm, c("univariate", "multivariate", "matrixvariate"))
+    } else if(getR6Class(type) %in% c("ProductSet","ExponentSet")) {
       variateForm = "multivariate"
+    } else {
+      variateForm = "univariate"
+    }
 
 
     #-------------------
@@ -439,7 +432,7 @@ Distribution$set("public","summary",function(full = TRUE,...){
     }
     cat("\n")
 
-    cat(" Support:",self$support()$getSymbol(), "\tScientific Type:",self$type()$getSymbol(),"\n")
+    cat(" Support:",self$support()$strprint(), "\tScientific Type:",self$type()$strprint(),"\n")
     cat("\n Traits:\t",self$valueSupport(),"; ",self$variateForm(), sep="")
     cat("\n Properties:\t", self$symmetry(),sep="")
     if(!inherits(a_kurt,"try-error")) cat(";",self$kurtosisType())
@@ -453,8 +446,8 @@ Distribution$set("public","summary",function(full = TRUE,...){
       cat(self$strprint())
     else
       cat(self$name)
-    cat("\nScientific Type:",self$type()$getSymbol(),"\t See $traits() for more")
-    cat("\nSupport:",self$support()$getSymbol(),"\t See $properties() for more")
+    cat("\nScientific Type:",self$type()$strprint(),"\t See $traits() for more")
+    cat("\nSupport:",self$support()$strprint(),"\t See $properties() for more")
   }
   cat("\n")
   invisible(self)
@@ -522,8 +515,8 @@ Distribution$set("public","variateForm",function(){
 #' @section R6 Usage: $type()
 #' @param object Distribution.
 #' @description Returns the scientific type of the distribution.
-#' @return An R6 object of class SetInterval.
-#' @seealso \code{\link{SetInterval}}
+#' @return An R6 object of class [set6::Set].
+#' @seealso [set6::Set]
 #' @export
 NULL
 Distribution$set("public","type",function(){
@@ -553,8 +546,8 @@ Distribution$set("public","properties",function(){
 #' greater than zero,
 #' \deqn{Supp(X) = \{x \ \in R: \ f_X(x) \ > \ 0\}}{Supp(X) = {x \epsilon R: f_X(x) > 0}}
 #' where \eqn{f_X} is the pmf if distribution \eqn{X} is discrete, otherwise the pdf.
-#' @return An R6 object of class SetInterval.
-#' @seealso \code{\link{SetInterval}} and \code{\link{properties}}
+#' @return An R6 object of class [set6::Set].
+#' @seealso [set6::Set] and \code{\link{properties}}
 #' @export
 NULL
 Distribution$set("public","support",function(){
@@ -586,7 +579,7 @@ Distribution$set("public","symmetry",function(){
 #' @export
 NULL
 Distribution$set("public","sup",function(){
-  return(self$support()$sup())
+  return(self$support()$upper)
 })
 
 #' @name inf
@@ -600,7 +593,7 @@ Distribution$set("public","sup",function(){
 #' @export
 NULL
 Distribution$set("public","inf",function(){
-  return(self$support()$inf())
+  return(self$support()$lower)
 })
 
 #' @name dmax
@@ -616,7 +609,7 @@ Distribution$set("public","inf",function(){
 #' @export
 NULL
 Distribution$set("public","dmax",function(){
-  return(self$support()$max())
+  return(self$support()$max)
 })
 
 #' @name dmin
@@ -632,7 +625,7 @@ Distribution$set("public","dmax",function(){
 #' @export
 NULL
 Distribution$set("public","dmin",function(){
-  return(self$support()$min())
+  return(self$support()$min)
 })
 
 #' @name kurtosisType
@@ -831,10 +824,10 @@ Distribution$set("public","cdf",function(x1, ..., lower.tail = TRUE, log.p = FAL
     return(NULL)
 
   if(testUnivariate(self)){
-    if(self$type()$class() == "integer")
+    if(self$type()$class == "integer")
        x1 <- floor(x1)
     cdf = numeric(length(x1))
-    cdf[x1 > self$sup()] = 1
+    cdf[x1 >= self$sup()] = 1
 
     if(getR6Class(self) %in% c("Empirical","WeightedDiscrete")){
       if(any(x1 >= self$inf() & x1 <= self$sup()))
@@ -1139,7 +1132,7 @@ Distribution$set("public","correlation",function(){
 #' @export
 NULL
 Distribution$set("public","liesInSupport",function(x, all = TRUE, bound = FALSE){
-  return(self$support()$liesInSetInterval(x, all, bound))
+  return(self$support()$contains(x, all, bound))
 })
 
 #' @name liesInType
@@ -1165,7 +1158,7 @@ Distribution$set("public","liesInSupport",function(x, all = TRUE, bound = FALSE)
 #' @export
 NULL
 Distribution$set("public","liesInType",function(x, all = TRUE, bound = FALSE){
-  return(self$type()$liesInSetInterval(x, all, bound))
+  return(self$type()$contains(x, all, bound))
 })
 
 #-------------------------------------------------------------
