@@ -52,8 +52,9 @@
 #'
 #' @export
 NULL
-ExoticStatistics <- R6::R6Class("ExoticStatistics", inherit = DistributionDecorator)
+ExoticStatistics <- R6Class("ExoticStatistics", inherit = DistributionDecorator)
 .distr6$decorators <- append(.distr6$decorators, list(ExoticStatistics = ExoticStatistics))
+ExoticStatistics$set("public","packages","pracma")
 #-------------------------------------------------------------
 # Public Methods - cdfAntiDeriv
 #-------------------------------------------------------------
