@@ -1,4 +1,3 @@
-#' @include SetInterval_SpecialSet.R
 #-------------------------------------------------------------
 # Kernel Documentation
 #-------------------------------------------------------------
@@ -75,15 +74,18 @@
 #'
 #' @export
 NULL
-Kernel <- R6::R6Class("Kernel", inherit = Distribution)
+Kernel <- R6Class("Kernel", inherit = Distribution)
 Kernel$set("public","initialize",function(...){
-  if(getR6Class(self) == "Kernel")
-    stop(paste0(getR6Class(self), " is an abstract class that can't be initialized. Use listKernels()
-to see the kernels currently implemented in distr6, or Distribution$new() to construct a custom Kernel."))
+  if(getR6Class(self) == "Kernel") {
+    stop(paste0(getR6Class(self), " is an abstract class that can't be initialized. Use listKernels() to see the kernels currently implemented in distr6, or Distribution$new() to construct a custom Kernel."))
+  }
+
+  assert_pkgload(self$packages)
 
   super$initialize(...)
 })
-Kernel$set("public","package","distr6")
+Kernel$set("public","package","This is now deprecated. Use $packages instead.")
+Kernel$set("public","packages", NULL)
 Kernel$set("private",".type","symmetric")
 Kernel$set("public","traits",function(){
   return(list(type = Reals$new(),
