@@ -93,12 +93,14 @@ NULL
 #-------------------------------------------------------------
 # SDistribution Definition
 #-------------------------------------------------------------
-SDistribution <- R6::R6Class("SDistribution", inherit = Distribution)
+SDistribution <- R6Class("SDistribution", inherit = Distribution)
 SDistribution$set("public","initialize",function(...){
   if(getR6Class(self) == "SDistribution")
     stop(paste0(getR6Class(self), " is an abstract class that can't be initialized. Use listDistributions()
     to see the probability distributions currently implemented in distr6."))
 
+  assert_pkgload(self$packages)
+
   super$initialize(...)
 })
 
@@ -109,7 +111,8 @@ SDistribution$set("public","setParameterValue",function(..., lst = NULL, error =
   super$setParameterValue(lst = lst, error = error)
   invisible(self)
 })
-SDistribution$set("public","package",NULL)
+SDistribution$set("public","package","This is now deprecated. Use $packages instead.")
+SDistribution$set("public","packages",NULL)
 # SDistribution$set("public","pgf",function(...){
 #   return(NaN)
 # })
