@@ -1,4 +1,4 @@
-#' @include SetInterval_SpecialSet.R ParameterSet.R
+
 #-------------------------------------------------------------
 # Noncentral Chi-Squared Distribution Documentation
 #-------------------------------------------------------------
@@ -44,11 +44,11 @@ NULL
 #-------------------------------------------------------------
 # ChiSquaredNoncentral Distribution Definition
 #-------------------------------------------------------------
-ChiSquaredNoncentral <- R6::R6Class("ChiSquaredNoncentral", inherit = SDistribution, lock_objects = FALSE)
+ChiSquaredNoncentral <- R6Class("ChiSquaredNoncentral", inherit = SDistribution, lock_objects = FALSE)
 ChiSquaredNoncentral$set("public", "name", "ChiSquaredNoncentral")
 ChiSquaredNoncentral$set("public", "short_name", "ChiSqNC")
 ChiSquaredNoncentral$set("public", "description", "Noncentral ChiSquared Probability Distribution")
-ChiSquaredNoncentral$set("public","package","stats")
+ChiSquaredNoncentral$set("public","packages","stats")
 
 ChiSquaredNoncentral$set("public", "mean", function(){
   return(self$getParameterValue("df") + self$getParameterValue("location"))
