@@ -1,4 +1,4 @@
-#' @include SetInterval_SpecialSet.R ParameterSet.R
+
 #-------------------------------------------------------------
 # Gumbel Distribution Documentation
 #-------------------------------------------------------------
@@ -43,11 +43,11 @@ NULL
 #-------------------------------------------------------------
 # Gumbel Distribution Definition
 #-------------------------------------------------------------
-Gumbel <- R6::R6Class("Gumbel", inherit = SDistribution, lock_objects = F)
+Gumbel <- R6Class("Gumbel", inherit = SDistribution, lock_objects = F)
 Gumbel$set("public","name","Gumbel")
 Gumbel$set("public","short_name","Gumb")
 Gumbel$set("public","description","Gumbel Probability Distribution.")
-Gumbel$set("public","package","distr6")
+Gumbel$set("public","packages", "pracma")
 
 Gumbel$set("public","mean",function(){
   return(self$getParameterValue("location") - digamma(1)*self$getParameterValue("scale"))
@@ -120,4 +120,4 @@ Gumbel$set("public","initialize",function(location = 0, scale = 1,
                               data.table::data.table(ShortName = "Gumb", ClassName = "Gumbel",
                                                      Type = "\u211D+", ValueSupport = "continuous",
                                                      VariateForm = "univariate",
-                                                     Package = "distr6"))
+                                                     Package = "pracma"))
