@@ -22,10 +22,10 @@ test_that("properties & traits",{
   expect_equal(mn$valueSupport(), "continuous")
   expect_equal(mn$variateForm(), "multivariate")
   expect_equal(mn$symmetry(), "asymmetric")
-  expect_equal(mn$inf(), 0)
-  expect_equal(mn$sup(), 1)
-  expect_equal(mn$dmin(), 0)
-  expect_equal(mn$dmax(), 1)
+  expect_equal(mn$inf(), Tuple$new(0,0,0))
+  expect_equal(mn$sup(), Tuple$new(1,1,1))
+  expect_equal(mn$dmin(), Tuple$new(0,0,0))
+  expect_equal(mn$dmax(), Tuple$new(1,1,1))
 })
 
 params = c(2,3)
